"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getQualifierMessage = getQualifierMessage;
exports.getSchemaName = getSchemaName;
/* ============================================================================
 * Copyright (c) Palo Alto Networks
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 * ========================================================================== */

function prettyName(schema, circular) {
  var _schema$title;
  if (schema.format) {
    return schema.format;
  }
  if (schema.allOf) {
    if (typeof schema.allOf[0] === "string") {
      // @ts-ignore
      if (schema.allOf[0].includes("circular")) {
        return schema.allOf[0];
      }
    }
    return "object";
  }
  if (schema.oneOf) {
    return "object";
  }
  if (schema.anyOf) {
    return "object";
  }
  if (schema.type === "object") {
    var _schema$xml$name, _schema$xml;
    return (_schema$xml$name = (_schema$xml = schema.xml) === null || _schema$xml === void 0 ? void 0 : _schema$xml.name) !== null && _schema$xml$name !== void 0 ? _schema$xml$name : schema.type;
    // return schema.type;
  }

  if (schema.type === "array") {
    var _schema$xml$name2, _schema$xml2;
    return (_schema$xml$name2 = (_schema$xml2 = schema.xml) === null || _schema$xml2 === void 0 ? void 0 : _schema$xml2.name) !== null && _schema$xml$name2 !== void 0 ? _schema$xml$name2 : schema.type;
    // return schema.type;
  }

  return (_schema$title = schema.title) !== null && _schema$title !== void 0 ? _schema$title : schema.type;
}
function getSchemaName(schema, circular) {
  var _prettyName;
  if (schema.items) {
    return prettyName(schema.items, circular) + "[]";
  }
  return (_prettyName = prettyName(schema, circular)) !== null && _prettyName !== void 0 ? _prettyName : "";
}
function getQualifierMessage(schema) {
  // TODO:
  // - uniqueItems
  // - maxProperties
  // - minProperties
  // - multipleOf
  if (!schema) {
    return undefined;
  }
  if (schema.items && schema.minItems === undefined && schema.maxItems === undefined) {
    return getQualifierMessage(schema.items);
  }
  let message = "**Possible values:** ";
  let qualifierGroups = [];
  if (schema.items && schema.items.enum) {
    if (schema.items.enum) {
      qualifierGroups.push(`[${schema.items.enum.map(e => `\`${e}\``).join(", ")}]`);
    }
  }
  if (schema.minLength || schema.maxLength) {
    let lengthQualifier = "";
    let minLength;
    let maxLength;
    if (schema.minLength && schema.minLength > 1) {
      minLength = `\`>= ${schema.minLength} characters\``;
    }
    if (schema.minLength && schema.minLength === 1) {
      minLength = `\`non-empty\``;
    }
    if (schema.maxLength) {
      maxLength = `\`<= ${schema.maxLength} characters\``;
    }
    if (minLength && !maxLength) {
      lengthQualifier += minLength;
    }
    if (maxLength && !minLength) {
      lengthQualifier += maxLength;
    }
    if (minLength && maxLength) {
      lengthQualifier += `${minLength} and ${maxLength}`;
    }
    qualifierGroups.push(lengthQualifier);
  }
  if (schema.minimum || schema.maximum || typeof schema.exclusiveMinimum === "number" || typeof schema.exclusiveMaximum === "number") {
    let minmaxQualifier = "";
    let minimum;
    let maximum;
    if (typeof schema.exclusiveMinimum === "number") {
      minimum = `\`> ${schema.exclusiveMinimum}\``;
    } else if (schema.minimum && !schema.exclusiveMinimum) {
      minimum = `\`>= ${schema.minimum}\``;
    } else if (schema.minimum && schema.exclusiveMinimum === true) {
      minimum = `\`> ${schema.minimum}\``;
    }
    if (typeof schema.exclusiveMaximum === "number") {
      maximum = `\`< ${schema.exclusiveMaximum}\``;
    } else if (schema.maximum && !schema.exclusiveMaximum) {
      maximum = `\`<= ${schema.maximum}\``;
    } else if (schema.maximum && schema.exclusiveMaximum === true) {
      maximum = `\`< ${schema.maximum}\``;
    }
    if (minimum && !maximum) {
      minmaxQualifier += minimum;
    }
    if (maximum && !minimum) {
      minmaxQualifier += maximum;
    }
    if (minimum && maximum) {
      minmaxQualifier += `${minimum} and ${maximum}`;
    }
    qualifierGroups.push(minmaxQualifier);
  }
  if (schema.pattern) {
    qualifierGroups.push(`Value must match regular expression \`${schema.pattern}\``);
  }

  // Check if discriminator mapping
  const discriminator = schema;
  if (discriminator.mapping) {
    const values = Object.keys(discriminator.mapping);
    qualifierGroups.push(`[${values.map(e => `\`${e}\``).join(", ")}]`);
  }
  if (schema.enum) {
    qualifierGroups.push(`[${schema.enum.map(e => `\`${e}\``).join(", ")}]`);
  }
  if (schema.minItems) {
    qualifierGroups.push(`\`>= ${schema.minItems}\``);
  }
  if (schema.maxItems) {
    qualifierGroups.push(`\`<= ${schema.maxItems}\``);
  }
  if (qualifierGroups.length === 0) {
    return undefined;
  }
  return message + qualifierGroups.join(", ");
}