"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TBody = TBody;
var _react = _interopRequireWildcard(require("react"));
var _clsx = _interopRequireDefault(require("clsx"));
var _reactMarkdown = _interopRequireDefault(require("react-markdown"));
var _stylesModule = _interopRequireDefault(require("./styles.module.css"));
var _TableRow = require("./TableRow");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
/* ============================================================================
 * Copyright (c) Palo Alto Networks
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 * ========================================================================== */

const PADDING_LEFT = 12;
function TBody({
  tableData,
  subfieldLevel = 0,
  ...props
}) {
  const [openRows, setOpenRows] = (0, _react.useState)([]);
  const toggleRow = index => {
    if (openRows.includes(index)) {
      setOpenRows(openRows.filter(i => i !== index));
    } else {
      setOpenRows([...openRows, index]);
    }
  };
  return <tbody {...props} className={(0, _clsx.default)(_stylesModule.default.tbody, props === null || props === void 0 ? void 0 : props.className)}>
      {tableData.map((row, index) => {
      const isSubfieldTableOpen = openRows.includes(index);
      // const hasPossibleValues =
      //   row.schema?.oneOf || row.schema?.anyOf || row.schema?.enum;

      const qualifierMessage = row !== null && row !== void 0 && row.qualifierMessage ? `${row.qualifierMessage}\n` : "";

      // const enumValues = getEnumRows(row);
      // if (enumValues.length) {
      //   console.log({ enumValues });
      // }
      return <_react.Fragment key={row.field}>
            <tr className={(0, _clsx.default)(_stylesModule.default.tr, !subfieldLevel && index === tableData.length - 1 && _stylesModule.default.hasBottomBorder)} style={{
          backgroundColor: subfieldLevel % 2 ? "var(--ifm-color-secondary-lighter)" : "#fff"
        }} onClick={() => row.subfields && toggleRow(index)}>
              <td className={(0, _clsx.default)(_stylesModule.default.fieldTh, _stylesModule.default.td)} style={{
            paddingLeft: `${(subfieldLevel + 1) * PADDING_LEFT}px`
          }}>
                <span className="font-semibold">{row.field}</span>
                {row.description ? <_reactMarkdown.default className="mt-1 text-xs">
                    {`${qualifierMessage}${row.description}`}
                  </_reactMarkdown.default> : null}

                {row.subfields ? <button className={(0, _clsx.default)("button", "button--secondary", _stylesModule.default.subfieldButton)}>
                    <Chevron className={(0, _clsx.default)(_stylesModule.default.subfieldButtonIcon)} style={{
                transform: `rotate(${isSubfieldTableOpen ? "0deg" : "180deg"})`
              }} />
                    {isSubfieldTableOpen ? "Hide" : "View"} subfields
                  </button> : null}
              </td>
              <td className={_stylesModule.default.requiredTh}>
                <Required isRequired={row.required} />
              </td>
              <td className={(0, _clsx.default)(_stylesModule.default.typeTh, _stylesModule.default.tdType)}>
                {row.type.charAt(0).toUpperCase() + row.type.slice(1)}
              </td>
            </tr>

            {row.subfields && (isSubfieldTableOpen ? <_TableRow.TR row={row} index={index} subfieldLevel={subfieldLevel + 1} /> : null)}
          </_react.Fragment>;
    })}
    </tbody>;
}
function Required({
  isRequired
}) {
  return <div className={(0, _clsx.default)(_stylesModule.default.requiredBubble, isRequired && _stylesModule.default.isRequired)}>
      <span>{isRequired ? "Required" : "Optional"}</span>
    </div>;
}
function Chevron(props) {
  return <svg xmlns="http://www.w3.org/2000/svg" width="16px" height="16px" viewBox="0 0 24 24" {...props}>
      <path fill="rgba(0,0,0,0.5)" d="M7.41 15.41L12 10.83l4.59 4.58L18 14l-6-6-6 6z"></path>
    </svg>;
}

// function getEnumRows(row: RowType) {
//   if (!row.schema) {
//     return [];
//   }

//   const enumValues = row.schema!.enum;

//   if (!enumValues) {
//     return [];
//   }

//   const enumRows = enumValues.map((value, index) => {
//     return {
//       field: value,
//       type: row.type,
//     };
//   });
//   return enumRows;
// }

// function getOneOfRows(row: RowType) {
//   if (!row.schema) {
//     return [];
//   }

//   const oneOfValues = row.schema!.oneOf;

//   if (!oneOfValues) {
//     return [];
//   }

//   const oneOfRows = oneOfValues.map((value, index) => {
//     const types = value.allOf;
//     let subfields: RowType[] = [];

//     if (types && types.length > 1) {
//       subfields = types.slice(1).map((subfield) => {
//         // TODO: get row info
//       });
//     }

//     let type = row.type;

//     if (types && types.length && typeof types[0] === "string") {
//       type = types[0];
//     }

//     return {
//       field: value.title,
//       type,
//       description: value?.description,
//       subfields,
//     };
//   });
//   return oneOfRows;
// }